/****************************************************************************
** Meta object code from reading C++ file 'standardpanel.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "standardpanel.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'standardpanel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StandardPLPanel_t {
    QByteArrayData data[25];
    char stringdata0[311];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StandardPLPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StandardPLPanel_t qt_meta_stringdata_StandardPLPanel = {
    {
QT_MOC_LITERAL(0, 0, 15), // "StandardPLPanel"
QT_MOC_LITERAL(1, 16, 11), // "viewChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 41, 11), // "setRootItem"
QT_MOC_LITERAL(5, 53, 16), // "playlist_item_t*"
QT_MOC_LITERAL(6, 70, 10), // "browseInto"
QT_MOC_LITERAL(7, 81, 8), // "showView"
QT_MOC_LITERAL(8, 90, 10), // "setWaiting"
QT_MOC_LITERAL(9, 101, 15), // "deleteSelection"
QT_MOC_LITERAL(10, 117, 15), // "handleExpansion"
QT_MOC_LITERAL(11, 133, 8), // "activate"
QT_MOC_LITERAL(12, 142, 15), // "gotoPlayingItem"
QT_MOC_LITERAL(13, 158, 6), // "search"
QT_MOC_LITERAL(14, 165, 10), // "searchText"
QT_MOC_LITERAL(15, 176, 13), // "searchDelayed"
QT_MOC_LITERAL(16, 190, 11), // "popupPlView"
QT_MOC_LITERAL(17, 202, 17), // "popupSelectColumn"
QT_MOC_LITERAL(18, 220, 11), // "popupAction"
QT_MOC_LITERAL(19, 232, 8), // "QAction*"
QT_MOC_LITERAL(20, 241, 12), // "increaseZoom"
QT_MOC_LITERAL(21, 254, 12), // "decreaseZoom"
QT_MOC_LITERAL(22, 267, 17), // "toggleColumnShown"
QT_MOC_LITERAL(23, 285, 10), // "cycleViews"
QT_MOC_LITERAL(24, 296, 14) // "updateViewport"

    },
    "StandardPLPanel\0viewChanged\0\0QModelIndex\0"
    "setRootItem\0playlist_item_t*\0browseInto\0"
    "showView\0setWaiting\0deleteSelection\0"
    "handleExpansion\0activate\0gotoPlayingItem\0"
    "search\0searchText\0searchDelayed\0"
    "popupPlView\0popupSelectColumn\0popupAction\0"
    "QAction*\0increaseZoom\0decreaseZoom\0"
    "toggleColumnShown\0cycleViews\0"
    "updateViewport"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StandardPLPanel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    2,  122,    2, 0x0a /* Public */,
       6,    1,  127,    2, 0x0a /* Public */,
       7,    1,  130,    2, 0x0a /* Public */,
       8,    1,  133,    2, 0x0a /* Public */,
       9,    0,  136,    2, 0x08 /* Private */,
      10,    1,  137,    2, 0x08 /* Private */,
      11,    1,  140,    2, 0x08 /* Private */,
       6,    0,  143,    2, 0x08 /* Private */,
       6,    1,  144,    2, 0x08 /* Private */,
      12,    0,  147,    2, 0x08 /* Private */,
      13,    1,  148,    2, 0x08 /* Private */,
      15,    1,  151,    2, 0x08 /* Private */,
      16,    1,  154,    2, 0x08 /* Private */,
      17,    1,  157,    2, 0x08 /* Private */,
      18,    1,  160,    2, 0x08 /* Private */,
      20,    0,  163,    2, 0x08 /* Private */,
      21,    0,  164,    2, 0x08 /* Private */,
      22,    1,  165,    2, 0x08 /* Private */,
      23,    0,  168,    2, 0x08 /* Private */,
      24,    0,  169,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 5, QMetaType::Bool,    2,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void, 0x80000000 | 19,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void StandardPLPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<StandardPLPanel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->viewChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->setRootItem((*reinterpret_cast< playlist_item_t*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->browseInto((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->showView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setWaiting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->deleteSelection(); break;
        case 6: _t->handleExpansion((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->activate((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 8: _t->browseInto(); break;
        case 9: _t->browseInto((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->gotoPlayingItem(); break;
        case 11: _t->search((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->searchDelayed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->popupPlView((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 14: _t->popupSelectColumn((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 15: _t->popupAction((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 16: _t->increaseZoom(); break;
        case 17: _t->decreaseZoom(); break;
        case 18: _t->toggleColumnShown((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->cycleViews(); break;
        case 20: _t->updateViewport(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (StandardPLPanel::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StandardPLPanel::viewChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject StandardPLPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_StandardPLPanel.data,
    qt_meta_data_StandardPLPanel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StandardPLPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StandardPLPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StandardPLPanel.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int StandardPLPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void StandardPLPanel::viewChanged(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
