/****************************************************************************
** Meta object code from reading C++ file 'external.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "external.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'external.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DialogHandler_t {
    QByteArrayData data[26];
    char stringdata0[304];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DialogHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DialogHandler_t qt_meta_stringdata_DialogHandler = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DialogHandler"
QT_MOC_LITERAL(1, 14, 14), // "errorDisplayed"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 5), // "title"
QT_MOC_LITERAL(4, 36, 4), // "text"
QT_MOC_LITERAL(5, 41, 14), // "loginDisplayed"
QT_MOC_LITERAL(6, 56, 14), // "vlc_dialog_id*"
QT_MOC_LITERAL(7, 71, 4), // "p_id"
QT_MOC_LITERAL(8, 76, 15), // "defaultUsername"
QT_MOC_LITERAL(9, 92, 11), // "b_ask_store"
QT_MOC_LITERAL(10, 104, 17), // "questionDisplayed"
QT_MOC_LITERAL(11, 122, 6), // "i_type"
QT_MOC_LITERAL(12, 129, 6), // "cancel"
QT_MOC_LITERAL(13, 136, 7), // "action1"
QT_MOC_LITERAL(14, 144, 7), // "action2"
QT_MOC_LITERAL(15, 152, 17), // "progressDisplayed"
QT_MOC_LITERAL(16, 170, 15), // "b_indeterminate"
QT_MOC_LITERAL(17, 186, 10), // "f_position"
QT_MOC_LITERAL(18, 197, 9), // "cancelled"
QT_MOC_LITERAL(19, 207, 15), // "progressUpdated"
QT_MOC_LITERAL(20, 223, 7), // "f_value"
QT_MOC_LITERAL(21, 231, 12), // "displayError"
QT_MOC_LITERAL(22, 244, 12), // "displayLogin"
QT_MOC_LITERAL(23, 257, 15), // "displayQuestion"
QT_MOC_LITERAL(24, 273, 15), // "displayProgress"
QT_MOC_LITERAL(25, 289, 14) // "updateProgress"

    },
    "DialogHandler\0errorDisplayed\0\0title\0"
    "text\0loginDisplayed\0vlc_dialog_id*\0"
    "p_id\0defaultUsername\0b_ask_store\0"
    "questionDisplayed\0i_type\0cancel\0action1\0"
    "action2\0progressDisplayed\0b_indeterminate\0"
    "f_position\0cancelled\0progressUpdated\0"
    "f_value\0displayError\0displayLogin\0"
    "displayQuestion\0displayProgress\0"
    "updateProgress"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DialogHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   74,    2, 0x06 /* Public */,
       5,    5,   79,    2, 0x06 /* Public */,
      10,    7,   90,    2, 0x06 /* Public */,
      15,    6,  105,    2, 0x06 /* Public */,
      18,    1,  118,    2, 0x06 /* Public */,
      19,    3,  121,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    2,  128,    2, 0x08 /* Private */,
      22,    5,  133,    2, 0x08 /* Private */,
      23,    7,  144,    2, 0x08 /* Private */,
      24,    6,  159,    2, 0x08 /* Private */,
      12,    1,  172,    2, 0x08 /* Private */,
      25,    3,  175,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    7,    3,    4,    8,    9,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    7,    3,    4,   11,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Float, QMetaType::QString,    7,    3,    4,   16,   17,   12,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Float, QMetaType::QString,    7,   20,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    7,    3,    4,    8,    9,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    7,    3,    4,   11,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Float, QMetaType::QString,    7,    3,    4,   16,   17,   12,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Float, QMetaType::QString,    7,   20,    4,

       0        // eod
};

void DialogHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DialogHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->errorDisplayed((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->loginDisplayed((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 2: _t->questionDisplayed((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7]))); break;
        case 3: _t->progressDisplayed((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< float(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 4: _t->cancelled((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1]))); break;
        case 5: _t->progressUpdated((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< float(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 6: _t->displayError((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->displayLogin((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 8: _t->displayQuestion((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7]))); break;
        case 9: _t->displayProgress((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< float(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 10: _t->cancel((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1]))); break;
        case 11: _t->updateProgress((*reinterpret_cast< vlc_dialog_id*(*)>(_a[1])),(*reinterpret_cast< float(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DialogHandler::*)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::errorDisplayed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DialogHandler::*)(vlc_dialog_id * , const QString & , const QString & , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::loginDisplayed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DialogHandler::*)(vlc_dialog_id * , const QString & , const QString & , int , const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::questionDisplayed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DialogHandler::*)(vlc_dialog_id * , const QString & , const QString & , bool , float , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::progressDisplayed)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DialogHandler::*)(vlc_dialog_id * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::cancelled)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DialogHandler::*)(vlc_dialog_id * , float , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogHandler::progressUpdated)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DialogHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DialogHandler.data,
    qt_meta_data_DialogHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DialogHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DialogHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DialogHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void DialogHandler::errorDisplayed(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DialogHandler::loginDisplayed(vlc_dialog_id * _t1, const QString & _t2, const QString & _t3, const QString & _t4, bool _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DialogHandler::questionDisplayed(vlc_dialog_id * _t1, const QString & _t2, const QString & _t3, int _t4, const QString & _t5, const QString & _t6, const QString & _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DialogHandler::progressDisplayed(vlc_dialog_id * _t1, const QString & _t2, const QString & _t3, bool _t4, float _t5, const QString & _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DialogHandler::cancelled(vlc_dialog_id * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DialogHandler::progressUpdated(vlc_dialog_id * _t1, float _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
struct qt_meta_stringdata_DialogWrapper_t {
    QByteArrayData data[4];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DialogWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DialogWrapper_t qt_meta_stringdata_DialogWrapper = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DialogWrapper"
QT_MOC_LITERAL(1, 14, 6), // "finish"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 6) // "result"

    },
    "DialogWrapper\0finish\0\0result"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DialogWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x09 /* Protected */,
       1,    0,   27,    2, 0x29 /* Protected | MethodCloned */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,

       0        // eod
};

void DialogWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DialogWrapper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->finish((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->finish(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DialogWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DialogWrapper.data,
    qt_meta_data_DialogWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DialogWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DialogWrapper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DialogWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_LoginDialogWrapper_t {
    QByteArrayData data[3];
    char stringdata0[27];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LoginDialogWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LoginDialogWrapper_t qt_meta_stringdata_LoginDialogWrapper = {
    {
QT_MOC_LITERAL(0, 0, 18), // "LoginDialogWrapper"
QT_MOC_LITERAL(1, 19, 6), // "accept"
QT_MOC_LITERAL(2, 26, 0) // ""

    },
    "LoginDialogWrapper\0accept\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LoginDialogWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void LoginDialogWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LoginDialogWrapper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->accept(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject LoginDialogWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<DialogWrapper::staticMetaObject>(),
    qt_meta_stringdata_LoginDialogWrapper.data,
    qt_meta_data_LoginDialogWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LoginDialogWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LoginDialogWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LoginDialogWrapper.stringdata0))
        return static_cast<void*>(this);
    return DialogWrapper::qt_metacast(_clname);
}

int LoginDialogWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DialogWrapper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_QuestionDialogWrapper_t {
    QByteArrayData data[4];
    char stringdata0[54];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QuestionDialogWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QuestionDialogWrapper_t qt_meta_stringdata_QuestionDialogWrapper = {
    {
QT_MOC_LITERAL(0, 0, 21), // "QuestionDialogWrapper"
QT_MOC_LITERAL(1, 22, 13), // "buttonClicked"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 16) // "QAbstractButton*"

    },
    "QuestionDialogWrapper\0buttonClicked\0"
    "\0QAbstractButton*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QuestionDialogWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void QuestionDialogWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QuestionDialogWrapper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->buttonClicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QuestionDialogWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<DialogWrapper::staticMetaObject>(),
    qt_meta_stringdata_QuestionDialogWrapper.data,
    qt_meta_data_QuestionDialogWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QuestionDialogWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QuestionDialogWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QuestionDialogWrapper.stringdata0))
        return static_cast<void*>(this);
    return DialogWrapper::qt_metacast(_clname);
}

int QuestionDialogWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DialogWrapper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_ProgressDialogWrapper_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ProgressDialogWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ProgressDialogWrapper_t qt_meta_stringdata_ProgressDialogWrapper = {
    {
QT_MOC_LITERAL(0, 0, 21) // "ProgressDialogWrapper"

    },
    "ProgressDialogWrapper"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ProgressDialogWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ProgressDialogWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ProgressDialogWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<DialogWrapper::staticMetaObject>(),
    qt_meta_stringdata_ProgressDialogWrapper.data,
    qt_meta_data_ProgressDialogWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ProgressDialogWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProgressDialogWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ProgressDialogWrapper.stringdata0))
        return static_cast<void*>(this);
    return DialogWrapper::qt_metacast(_clname);
}

int ProgressDialogWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DialogWrapper::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
