/****************************************************************************
** Meta object code from reading C++ file 'dialogs_provider.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "dialogs_provider.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialogs_provider.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DialogsProvider_t {
    QByteArrayData data[52];
    char stringdata0[718];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DialogsProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DialogsProvider_t qt_meta_stringdata_DialogsProvider = {
    {
QT_MOC_LITERAL(0, 0, 15), // "DialogsProvider"
QT_MOC_LITERAL(1, 16, 18), // "toolBarConfUpdated"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 18), // "releaseMouseEvents"
QT_MOC_LITERAL(4, 55, 14), // "playlistDialog"
QT_MOC_LITERAL(5, 70, 15), // "bookmarksDialog"
QT_MOC_LITERAL(6, 86, 15), // "mediaInfoDialog"
QT_MOC_LITERAL(7, 102, 16), // "mediaCodecDialog"
QT_MOC_LITERAL(8, 119, 11), // "prefsDialog"
QT_MOC_LITERAL(9, 131, 14), // "extendedDialog"
QT_MOC_LITERAL(10, 146, 13), // "synchroDialog"
QT_MOC_LITERAL(11, 160, 14), // "messagesDialog"
QT_MOC_LITERAL(12, 175, 7), // "sendKey"
QT_MOC_LITERAL(13, 183, 3), // "key"
QT_MOC_LITERAL(14, 187, 9), // "vlmDialog"
QT_MOC_LITERAL(15, 197, 10), // "helpDialog"
QT_MOC_LITERAL(16, 208, 11), // "aboutDialog"
QT_MOC_LITERAL(17, 220, 14), // "gotoTimeDialog"
QT_MOC_LITERAL(18, 235, 22), // "podcastConfigureDialog"
QT_MOC_LITERAL(19, 258, 13), // "toolbarDialog"
QT_MOC_LITERAL(20, 272, 12), // "pluginDialog"
QT_MOC_LITERAL(21, 285, 9), // "epgDialog"
QT_MOC_LITERAL(22, 295, 12), // "setPopupMenu"
QT_MOC_LITERAL(23, 308, 16), // "destroyPopupMenu"
QT_MOC_LITERAL(24, 325, 21), // "openFileGenericDialog"
QT_MOC_LITERAL(25, 347, 19), // "intf_dialog_args_t*"
QT_MOC_LITERAL(26, 367, 16), // "simpleOpenDialog"
QT_MOC_LITERAL(27, 384, 10), // "openDialog"
QT_MOC_LITERAL(28, 395, 14), // "openDiscDialog"
QT_MOC_LITERAL(29, 410, 14), // "openFileDialog"
QT_MOC_LITERAL(30, 425, 13), // "openUrlDialog"
QT_MOC_LITERAL(31, 439, 13), // "openNetDialog"
QT_MOC_LITERAL(32, 453, 17), // "openCaptureDialog"
QT_MOC_LITERAL(33, 471, 14), // "PLAppendDialog"
QT_MOC_LITERAL(34, 486, 3), // "tab"
QT_MOC_LITERAL(35, 490, 14), // "MLAppendDialog"
QT_MOC_LITERAL(36, 505, 9), // "PLOpenDir"
QT_MOC_LITERAL(37, 515, 11), // "PLAppendDir"
QT_MOC_LITERAL(38, 527, 15), // "streamingDialog"
QT_MOC_LITERAL(39, 543, 8), // "QWidget*"
QT_MOC_LITERAL(40, 552, 6), // "parent"
QT_MOC_LITERAL(41, 559, 4), // "mrls"
QT_MOC_LITERAL(42, 564, 8), // "b_stream"
QT_MOC_LITERAL(43, 573, 7), // "options"
QT_MOC_LITERAL(44, 581, 23), // "openAndStreamingDialogs"
QT_MOC_LITERAL(45, 605, 25), // "openAndTranscodingDialogs"
QT_MOC_LITERAL(46, 631, 13), // "openAPlaylist"
QT_MOC_LITERAL(47, 645, 21), // "savePlayingToPlaylist"
QT_MOC_LITERAL(48, 667, 17), // "loadSubtitlesFile"
QT_MOC_LITERAL(49, 685, 4), // "quit"
QT_MOC_LITERAL(50, 690, 10), // "menuAction"
QT_MOC_LITERAL(51, 701, 16) // "menuUpdateAction"

    },
    "DialogsProvider\0toolBarConfUpdated\0\0"
    "releaseMouseEvents\0playlistDialog\0"
    "bookmarksDialog\0mediaInfoDialog\0"
    "mediaCodecDialog\0prefsDialog\0"
    "extendedDialog\0synchroDialog\0"
    "messagesDialog\0sendKey\0key\0vlmDialog\0"
    "helpDialog\0aboutDialog\0gotoTimeDialog\0"
    "podcastConfigureDialog\0toolbarDialog\0"
    "pluginDialog\0epgDialog\0setPopupMenu\0"
    "destroyPopupMenu\0openFileGenericDialog\0"
    "intf_dialog_args_t*\0simpleOpenDialog\0"
    "openDialog\0openDiscDialog\0openFileDialog\0"
    "openUrlDialog\0openNetDialog\0"
    "openCaptureDialog\0PLAppendDialog\0tab\0"
    "MLAppendDialog\0PLOpenDir\0PLAppendDir\0"
    "streamingDialog\0QWidget*\0parent\0mrls\0"
    "b_stream\0options\0openAndStreamingDialogs\0"
    "openAndTranscodingDialogs\0openAPlaylist\0"
    "savePlayingToPlaylist\0loadSubtitlesFile\0"
    "quit\0menuAction\0menuUpdateAction"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DialogsProvider[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      46,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  244,    2, 0x06 /* Public */,
       3,    0,  245,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  246,    2, 0x0a /* Public */,
       5,    0,  247,    2, 0x0a /* Public */,
       6,    0,  248,    2, 0x0a /* Public */,
       7,    0,  249,    2, 0x0a /* Public */,
       8,    0,  250,    2, 0x0a /* Public */,
       9,    0,  251,    2, 0x0a /* Public */,
      10,    0,  252,    2, 0x0a /* Public */,
      11,    0,  253,    2, 0x0a /* Public */,
      12,    1,  254,    2, 0x0a /* Public */,
      14,    0,  257,    2, 0x0a /* Public */,
      15,    0,  258,    2, 0x0a /* Public */,
      16,    0,  259,    2, 0x0a /* Public */,
      17,    0,  260,    2, 0x0a /* Public */,
      18,    0,  261,    2, 0x0a /* Public */,
      19,    0,  262,    2, 0x0a /* Public */,
      20,    0,  263,    2, 0x0a /* Public */,
      21,    0,  264,    2, 0x0a /* Public */,
      22,    0,  265,    2, 0x0a /* Public */,
      23,    0,  266,    2, 0x0a /* Public */,
      24,    1,  267,    2, 0x0a /* Public */,
      26,    0,  270,    2, 0x0a /* Public */,
      27,    0,  271,    2, 0x0a /* Public */,
      28,    0,  272,    2, 0x0a /* Public */,
      29,    0,  273,    2, 0x0a /* Public */,
      30,    0,  274,    2, 0x0a /* Public */,
      31,    0,  275,    2, 0x0a /* Public */,
      32,    0,  276,    2, 0x0a /* Public */,
      33,    1,  277,    2, 0x0a /* Public */,
      33,    0,  280,    2, 0x2a /* Public | MethodCloned */,
      35,    1,  281,    2, 0x0a /* Public */,
      35,    0,  284,    2, 0x2a /* Public | MethodCloned */,
      36,    0,  285,    2, 0x0a /* Public */,
      37,    0,  286,    2, 0x0a /* Public */,
      38,    4,  287,    2, 0x0a /* Public */,
      38,    3,  296,    2, 0x2a /* Public | MethodCloned */,
      38,    2,  303,    2, 0x2a /* Public | MethodCloned */,
      44,    0,  308,    2, 0x0a /* Public */,
      45,    0,  309,    2, 0x0a /* Public */,
      46,    0,  310,    2, 0x0a /* Public */,
      47,    0,  311,    2, 0x0a /* Public */,
      48,    0,  312,    2, 0x0a /* Public */,
      49,    0,  313,    2, 0x0a /* Public */,
      50,    1,  314,    2, 0x08 /* Private */,
      51,    1,  317,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 39, QMetaType::QStringList, QMetaType::Bool, QMetaType::QStringList,   40,   41,   42,   43,
    QMetaType::Void, 0x80000000 | 39, QMetaType::QStringList, QMetaType::Bool,   40,   41,   42,
    QMetaType::Void, 0x80000000 | 39, QMetaType::QStringList,   40,   41,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,    2,
    QMetaType::Void, QMetaType::QObjectStar,    2,

       0        // eod
};

void DialogsProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DialogsProvider *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->toolBarConfUpdated(); break;
        case 1: _t->releaseMouseEvents(); break;
        case 2: _t->playlistDialog(); break;
        case 3: _t->bookmarksDialog(); break;
        case 4: _t->mediaInfoDialog(); break;
        case 5: _t->mediaCodecDialog(); break;
        case 6: _t->prefsDialog(); break;
        case 7: _t->extendedDialog(); break;
        case 8: _t->synchroDialog(); break;
        case 9: _t->messagesDialog(); break;
        case 10: _t->sendKey((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->vlmDialog(); break;
        case 12: _t->helpDialog(); break;
        case 13: _t->aboutDialog(); break;
        case 14: _t->gotoTimeDialog(); break;
        case 15: _t->podcastConfigureDialog(); break;
        case 16: _t->toolbarDialog(); break;
        case 17: _t->pluginDialog(); break;
        case 18: _t->epgDialog(); break;
        case 19: _t->setPopupMenu(); break;
        case 20: _t->destroyPopupMenu(); break;
        case 21: _t->openFileGenericDialog((*reinterpret_cast< intf_dialog_args_t*(*)>(_a[1]))); break;
        case 22: _t->simpleOpenDialog(); break;
        case 23: _t->openDialog(); break;
        case 24: _t->openDiscDialog(); break;
        case 25: _t->openFileDialog(); break;
        case 26: _t->openUrlDialog(); break;
        case 27: _t->openNetDialog(); break;
        case 28: _t->openCaptureDialog(); break;
        case 29: _t->PLAppendDialog((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 30: _t->PLAppendDialog(); break;
        case 31: _t->MLAppendDialog((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->MLAppendDialog(); break;
        case 33: _t->PLOpenDir(); break;
        case 34: _t->PLAppendDir(); break;
        case 35: _t->streamingDialog((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< QStringList(*)>(_a[4]))); break;
        case 36: _t->streamingDialog((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 37: _t->streamingDialog((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 38: _t->openAndStreamingDialogs(); break;
        case 39: _t->openAndTranscodingDialogs(); break;
        case 40: _t->openAPlaylist(); break;
        case 41: _t->savePlayingToPlaylist(); break;
        case 42: _t->loadSubtitlesFile(); break;
        case 43: _t->quit(); break;
        case 44: _t->menuAction((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 45: _t->menuUpdateAction((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DialogsProvider::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogsProvider::toolBarConfUpdated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DialogsProvider::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DialogsProvider::releaseMouseEvents)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DialogsProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DialogsProvider.data,
    qt_meta_data_DialogsProvider,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DialogsProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogsProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DialogsProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DialogsProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void DialogsProvider::toolBarConfUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DialogsProvider::releaseMouseEvents()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
